@@ -2,6 +2,10 @@
 /// Dialog boxes to prompt the user for things.
 pub mod dialogs;
 pub mod parse;
+#[cfg(feature = "config")]
+mod keybinds;
+#[cfg(feature = "config")]
+pub use keybinds::KeybindsRaw;
 mod run;
 #[cfg(feature = "timing")]
 /// Functions to format times.
